@@ -20,6 +20,7 @@
 #include "activatable.h"
 #include "adjustment.h"
 #include "alignment.h"
+#include "application.h"
 #include "arrow.h"
 #include "aspectframe.h"
 #include "assistant.h"
@@ -80,7 +81,6 @@
 #include "imagemenuitem.h"
 #include "infobar.h"
 #include "invisible.h"
-#include "item.h"
 #include "label.h"
 #include "layout.h"
 #include "linkbutton.h"
@@ -131,6 +131,7 @@
 #include "separatortoolitem.h"
 #include "settings.h"
 #include "sizegroup.h"
+#include "sizerequest.h"
 #include "socket.h"
 #include "spinbutton.h"
 #include "spinner.h"
@@ -177,6 +178,7 @@
 #include "volumebutton.h"
 #include "widget.h"
 #include "window.h"
+#include "wrapbox.h"
 #include "pagesetupunixdialog.h"
 #include "printer.h"
 #include "printjob.h"
@@ -194,6 +196,7 @@ GType gtk_action_get_type(void);
 GType gtk_action_group_get_type(void);
 GType gtk_adjustment_get_type(void);
 GType gtk_alignment_get_type(void);
+GType gtk_application_get_type(void);
 GType gtk_arrow_get_type(void);
 GType gtk_aspect_frame_get_type(void);
 GType gtk_assistant_get_type(void);
@@ -253,7 +256,6 @@ GType gtk_image_get_type(void);
 GType gtk_image_menu_item_get_type(void);
 GType gtk_info_bar_get_type(void);
 GType gtk_invisible_get_type(void);
-GType gtk_item_get_type(void);
 GType gtk_label_get_type(void);
 GType gtk_layout_get_type(void);
 GType gtk_link_button_get_type(void);
@@ -355,6 +357,7 @@ GType gtk_volume_button_get_type(void);
 GType gtk_widget_get_type(void);
 GType gtk_window_get_type(void);
 GType gtk_window_group_get_type(void);
+GType gtk_wrap_box_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
@@ -376,6 +379,7 @@ namespace Gtk {  class Action_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gtk {  class ActionGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Adjustment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Assistant_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -435,7 +439,6 @@ namespace Gtk {  class Image_Class { public: static Glib::ObjectBase* wrap_new(G
 namespace Gtk {  class ImageMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class InfoBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Invisible_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class Item_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Label_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Layout_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class LinkButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -537,6 +540,7 @@ namespace Gtk {  class VolumeButton_Class { public: static Glib::ObjectBase* wra
 namespace Gtk {  class Widget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Window_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class WindowGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class WrapBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace Gtk { 
 
@@ -558,6 +562,7 @@ void wrap_init()
   Glib::wrap_register(gtk_action_group_get_type(), &Gtk::ActionGroup_Class::wrap_new);
   Glib::wrap_register(gtk_adjustment_get_type(), &Gtk::Adjustment_Class::wrap_new);
   Glib::wrap_register(gtk_alignment_get_type(), &Gtk::Alignment_Class::wrap_new);
+  Glib::wrap_register(gtk_application_get_type(), &Gtk::Application_Class::wrap_new);
   Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
   Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
   Glib::wrap_register(gtk_assistant_get_type(), &Gtk::Assistant_Class::wrap_new);
@@ -617,7 +622,6 @@ void wrap_init()
   Glib::wrap_register(gtk_image_menu_item_get_type(), &Gtk::ImageMenuItem_Class::wrap_new);
   Glib::wrap_register(gtk_info_bar_get_type(), &Gtk::InfoBar_Class::wrap_new);
   Glib::wrap_register(gtk_invisible_get_type(), &Gtk::Invisible_Class::wrap_new);
-  Glib::wrap_register(gtk_item_get_type(), &Gtk::Item_Class::wrap_new);
   Glib::wrap_register(gtk_label_get_type(), &Gtk::Label_Class::wrap_new);
   Glib::wrap_register(gtk_layout_get_type(), &Gtk::Layout_Class::wrap_new);
   Glib::wrap_register(gtk_link_button_get_type(), &Gtk::LinkButton_Class::wrap_new);
@@ -719,6 +723,7 @@ void wrap_init()
   Glib::wrap_register(gtk_widget_get_type(), &Gtk::Widget_Class::wrap_new);
   Glib::wrap_register(gtk_window_get_type(), &Gtk::Window_Class::wrap_new);
   Glib::wrap_register(gtk_window_group_get_type(), &Gtk::WindowGroup_Class::wrap_new);
+  Glib::wrap_register(gtk_wrap_box_get_type(), &Gtk::WrapBox_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gtk::AboutDialog::get_type();
@@ -728,6 +733,7 @@ void wrap_init()
   Gtk::ActionGroup::get_type();
   Gtk::Adjustment::get_type();
   Gtk::Alignment::get_type();
+  Gtk::Application::get_type();
   Gtk::Arrow::get_type();
   Gtk::AspectFrame::get_type();
   Gtk::Assistant::get_type();
@@ -787,7 +793,6 @@ void wrap_init()
   Gtk::ImageMenuItem::get_type();
   Gtk::InfoBar::get_type();
   Gtk::Invisible::get_type();
-  Gtk::Item::get_type();
   Gtk::Label::get_type();
   Gtk::Layout::get_type();
   Gtk::LinkButton::get_type();
@@ -889,6 +894,7 @@ void wrap_init()
   Gtk::Widget::get_type();
   Gtk::Window::get_type();
   Gtk::WindowGroup::get_type();
+  Gtk::WrapBox::get_type();
 
 } // wrap_init()
 
